@@ -3,9 +3,12 @@ use strict;
 use vars qw(@ISA $VERSION);
 use POE::Queue;
 
+@ISA = qw(POE::Queue);
+
 BEGIN {
-  @ISA = qw(POE::Queue);
-  $VERSION = '0.005_02';
+  require Exporter;
+  @ISA = qw(Exporter);
+  $VERSION = '0.001';
   eval {
     # try XSLoader first, DynaLoader has annoying baggage
     require XSLoader;
@@ -31,8 +34,6 @@ sub import {
   *{ $package . '::ITEM_PAYLOAD'  } = \&ITEM_PAYLOAD;
 }
 
-sub CLONE_SKIP { 1 }
-
 # everything else is XS
 1;
 
@@ -54,25 +55,9 @@ It implements a priority queue using C, with an XS interface supplied.
 The current implementation could use some optimization, especially for
 large queues.
 
-Please see the POE::Queue documentation, which explains this one's
+Please see the POE::Queue documentation, which explainsthis one's
 functions, features, and behavior.
 
-The following extra methods are added beyond POE::Queue::Array:
-
-=over
-
-=item dump
-
-Dumps the internal structure of the queue to stderr.
-
-=item verify
-
-Does limited verification of the structure of the queue.  If the
-verification fails then a message is sent to stderr and the queue is
-dumped as with the dump() method, and your program will exit.
-
-=back
-
 =head1 SEE ALSO
 
 POE, POE::Queue, POE::Queue::Array
@@ -87,6 +72,10 @@ Some possible improvements include:
 
 =item *
 
+use binary searches for large queues
+
+=item *
+
 use a B-Tree for the queue (not a binary tree, a B-Tree), though this
 would require a module rename.
 
@@ -103,10 +92,6 @@ those array refs.
 
 =back
 
-=head1 LICENSE
-
-POE::XS::Queue::Array is licensed under the same terms as Perl itself.
-
 =head1 AUTHOR
 
 Tony Cook <tonyc@cpan.org>
